<?php

namespace Drupal\redirect_bulk\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for Node Autocomplete.
 */
class RedirectBulkController extends ControllerBase {

  /**
   * Handle the autocomplete for node titles.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The incoming request.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   A JSON response containing the autocomplete results.
   */
  public function handleAutocomplete(Request $request) {
    $matches = [];
    $string = $request->query->get('q');

    if ($string) {
      // Create an entity query for nodes matching the search string.
      $query = $this->entityTypeManager()->getStorage('node')->getQuery()
        ->condition('title', '%' . $string . '%', 'LIKE')
        // Only active nodes.
        ->condition('status', 1)
        ->range(0, 10)
        ->accessCheck(TRUE)
        ->execute();

      // Load the nodes matching the query.
      $nodes = $this->entityTypeManager()->getStorage('node')->loadMultiple($query);
      foreach ($nodes as $node) {
        $path = $node->toUrl()->getInternalPath();
        $matches[] = [
          'value' => $path,
          'label' => $node->label(),
        ];
      }
    }

    // Return the matches as a JSON response.
    return new JsonResponse($matches);
  }

}
